@@ -1,3 +1,4 @@
+import copy
 import inspect
 import os.path
 import random
@@ -274,3 +275,23 @@ def sort_dfs(data, sort_key="serial_index", children_key="children", reverse=Fal
                 # 递归排序子元素
                 for sub_element in data[children_key]:
                     sort_dfs(sub_element, sort_key=sort_key, children_key=children_key, reverse=reverse)
+
+
+def tree2list(data_tree, key="children", parent_key="parent_key", data_key="key"):
+    data_tree_tmp = copy.deepcopy(data_tree)
+    data = []
+
+    def temp(tree, _parent_key=""):
+        if tree.get(key):
+            for _child in tree.get(key):
+                _child[parent_key] = tree.get(data_key)
+                temp(_child, _parent_key)
+            tree.pop(key)
+        data.append(tree)
+
+    if isinstance(data_tree_tmp, list):
+        for x in data_tree_tmp:
+            temp(x, parent_key)
+    elif isinstance(data_tree_tmp, dict):
+        temp(data_tree, parent_key)
+    return data
